@@ -109,8 +109,6 @@ class DriverAPI(RequestHandler):
         """
         raise NotImplementedError
 
-    find_by_css_selector = find_by_css
-
     def find_by_xpath(self, xpath):
         """
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`, using a xpath selector to query the
@@ -220,6 +218,12 @@ class DriverAPI(RequestHandler):
         """
         raise NotImplementedError
 
+    def fill_form(self, field_values):
+        """
+        Fill the fields identified by ``name`` with the content specified by ``value`` in a dict.
+        """
+        raise NotImplementedError
+
     def choose(self, name, value):
         """
         Chooses a value in a radio buttons group.
@@ -315,8 +319,6 @@ class DriverAPI(RequestHandler):
         """
         raise NotImplementedError
 
-    is_element_present_by_css_selector = is_element_present_by_css
-
     def is_element_not_present_by_css(self, css_selector, wait_time=None):
         """
         Verify if the element is not present in the current page by css, and wait the specified time in ``wait_time``.
@@ -325,8 +327,6 @@ class DriverAPI(RequestHandler):
         """
         raise NotImplementedError
 
-    is_element_not_present_by_css_selector = is_element_not_present_by_css
-
     def is_element_present_by_xpath(self, xpath, wait_time=None):
         """
         Verify if the element is present in the current page by xpath, and wait the specified time in ``wait_time``.
@@ -498,5 +498,19 @@ class ElementAPI(object):
         """
         raise NotImplementedError
 
+    def fill(self, value):
+        """
+        Fill the field with the content specified by ``value``.
+        """
+        raise NotImplementedError
+
+    def type(self, value, slowly=False):
+        """
+        Types the ``value`` in the field.
+
+        It's useful to test javascript events like keyPress, keyUp, keyDown, etc.
+        """
+        raise NotImplementedError
+
     def __getitem__(self, attribute):
         raise NotImplementedError
