@@ -2,7 +2,6 @@ from lxml.cssselect import CSSSelector
 from zope.testbrowser.browser import Browser
 from splinter.element_list import ElementList
 from splinter.driver import DriverAPI, ElementAPI
-from splinter.utils import warn_deprecated
 from splinter.cookie_manager import CookieManagerAPI
 
 import mimetypes
@@ -92,8 +91,6 @@ class ZopeTestBrowser(DriverAPI):
         xpath = CSSSelector(selector).path
         return self.find_by_xpath(xpath, original_find="css", original_selector=selector)
 
-    find_by_css_selector = warn_deprecated(find_by_css, 'find_by_css_selector')
-
     def find_by_xpath(self, xpath, original_find=None, original_selector=None):
         html = lxml.html.fromstring(self.html)
 
@@ -149,7 +146,21 @@ class ZopeTestBrowser(DriverAPI):
     def fill(self, name, value):
         self.find_by_name(name=name).first._control.value = value
 
-    fill_in = warn_deprecated(fill, 'fill_in')
+    def fill_form(self, field_values):
+        for name, value in field_values.items():
+            element = self.find_by_name(name)
+            control = element.first._control
+            if control.type == 'text':
+                control.value = value
+            elif control.type == 'checkbox':
+                if value:
+                    control.value = control.options
+                else:
+                    control.value = []
+            elif control.type == 'radio':
+                control.value = [option for option in control.options if option == value]
+            elif control.type == 'select':
+                control.value = [value]
 
     def choose(self, name, value):
         control = self._browser.getControl(name=name)
@@ -262,6 +273,9 @@ class ZopeTestBrowserControlElement(ElementAPI):
     def click(self):
         return self._control.click()
 
+    def fill(self, value):
+        self._control.value = value
+
 
 class ZopeTestBrowserOptionElement(ElementAPI):
 
